diaMeasure: Computes a Dialectometrical measure

Usage Arguments Details Examples

View source: R/diaMeasure.R

Usage

1
2
diaMeasure(data, formula, value.var, measure = c("ird", "ipi", "levenshtein",
  "iri", "ipd"), binaryIndex = c("dice", "jaccard"), subset)

Arguments

data

object coercible to data.frame containing the data.

formula

formula indicating which variables represent ids and variables, see details.

value.var

character of length 1 indicating the variable containing the values.

measure

character of length 1 indiciating the selected.

binaryIndex

character of length 1 indicating the binary index to use in multiple answers

subset

index indicating which subset of data to take.

Details

Formula takes a expression of type 'var1 + var2 ~ var3' indication the index variables on the LHS and reponse variables on the RHS.

Examples

1
2
3
data(dsample)
measure <- diaMeasure(dsample, gender + location ~ question, 'answer', 'ird')
print(measure)

usobiaga/diaMeasures documentation built on May 3, 2019, 2:38 p.m.